@@ -119,7 +119,8 @@ namespace xt
     template <class S, class... Args>
     inline void check_index(const S& shape, Args... args)
     {
-        detail::check_index_impl<S, 0>(shape, args...);
+        using value_type = typename S::value_type;
+        detail::check_index_impl<S, 0>(shape, static_cast<value_type>(args)...);
     }
 
     template <class S, class It>
