@@ -80,6 +80,7 @@ namespace xt
     public:
 
         using size_type = T;
+        using self_type = xrange<T>;
 
         xrange() = default;
         xrange(size_type min_val, size_type max_val) noexcept;
@@ -93,6 +94,9 @@ namespace xt
 
         bool contains(size_type i) const noexcept;
 
+        bool operator==(const self_type& rhs) const noexcept;
+        bool operator!=(const self_type& rhs) const noexcept;
+
     private:
 
         size_type m_min;
@@ -109,6 +113,7 @@ namespace xt
     public:
 
         using size_type = T;
+        using self_type = xstepped_range<T>;
 
         xstepped_range() = default;
         xstepped_range(size_type min_val, size_type max_val, size_type step) noexcept;
@@ -122,6 +127,9 @@ namespace xt
 
         bool contains(size_type i) const noexcept;
 
+        bool operator==(const self_type& rhs) const noexcept;
+        bool operator!=(const self_type& rhs) const noexcept;
+
     private:
 
         size_type m_min;
@@ -139,6 +147,7 @@ namespace xt
     public:
 
         using size_type = T;
+        using self_type = xall<T>;
 
         xall() = default;
         explicit xall(size_type size) noexcept;
@@ -152,6 +161,9 @@ namespace xt
 
         bool contains(size_type i) const noexcept;
 
+        bool operator==(const self_type& rhs) const noexcept;
+        bool operator!=(const self_type& rhs) const noexcept;
+
     private:
 
         size_type m_size;
@@ -594,6 +606,18 @@ namespace xt
         return i >= m_min && i < m_min + m_size;
     }
 
+    template <class T>
+    inline bool xrange<T>::operator==(const self_type& rhs) const noexcept
+    {
+        return (m_min == rhs.m_min) && (m_size == rhs.m_size);
+    }
+
+    template <class T>
+    inline bool xrange<T>::operator!=(const self_type& rhs) const noexcept
+    {
+        return !(*this == rhs);
+    }
+
     /********************************
      * xtepped_range implementation *
      ********************************/
@@ -641,6 +665,18 @@ namespace xt
         return i >= m_min && i < m_min + m_size * m_step && ((i - m_min) % m_step == 0);
     }
 
+    template <class T>
+    inline bool xstepped_range<T>::operator==(const self_type& rhs) const noexcept
+    {
+        return (m_min == rhs.m_min) && (m_size == rhs.m_size) && (m_step == rhs.m_step);
+    }
+
+    template <class T>
+    inline bool xstepped_range<T>::operator!=(const self_type& rhs) const noexcept
+    {
+        return !(*this == rhs);
+    }
+
     /***********************
      * xall implementation *
      ***********************/
@@ -687,6 +723,18 @@ namespace xt
         return i < m_size;
     }
 
+    template <class T>
+    inline bool xall<T>::operator==(const self_type& rhs) const noexcept
+    {
+        return m_size == rhs.m_size;
+    }
+
+    template <class T>
+    inline bool xall<T>::operator!=(const self_type& rhs) const noexcept
+    {
+        return !(*this == rhs);
+    }
+
     /****************************
      * xellipsis implementation *
      ****************************/
