@@ -785,7 +785,9 @@ namespace xt
                 resize_container(m_index, m_e.dimension());
                 resize_container(m_strides, m_e.dimension());
                 m_size = compute_size(m_e.shape());
-                m_layout = m_e.layout();
+                // Fallback to DEFAULT_LAYOUT when the underlying layout is not
+                // row-major or column major.
+                m_layout = default_assignable_layout(m_e.layout());
                 compute_strides(m_e.shape(), m_layout, m_strides);
             }
 
